;; Generated package description from vcl-mode.el  -*- no-byte-compile: t -*-
(define-package "vcl-mode" "1.1.0.20201127.191542" "Major mode for Varnish Configuration Language" 'nil :commit "ff7331de91e399af4b222cad0b0a1d445f82b333" :url "https://elpa.gnu.org/packages/vcl-mode.html" :authors '(("Sergey Poznyakoff" . "gray@gnu.org.ua")) :maintainer '("Sergey Poznyakoff" . "gray@gnu.org.ua") :keywords '("varnish" "vcl"))
